MCD triple_111
Utiliser ( carnet u1, projet u2, technicien u1 u2 )

- Le champ carnet fait partie de la clé primaire de la table. Sa table d'origine (Carnet) ayant été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre à la contrainte d'unicité 1.
- Le champ projet fait partie de la clé primaire de la table. Sa table d'origine (Projet) ayant été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre à la contrainte d'unicité 2.
- Le champ technicien est un simple attribut. Il a migré directement à partir de l'entité Technicien en perdant son caractère identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère. Il obéit par contre aux contraintes d'unicité 1 et 2.

NB. Les tables Carnet, Projet et Technicien ont été supprimées car elles étaient réduites à la clé primaire de leur entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.